@@ -12,11 +12,7 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-# -*- coding: utf-8 -*-
-"""
-A collection of common shape operations needed for broadcasting
-samples from probability distributions for stochastic nodes in PyMC.
-"""
+"""Common shape operations to broadcast samples from probability distributions for stochastic nodes in PyMC."""
 
 import warnings
 
@@ -51,7 +47,7 @@ from pymc.util import _add_future_warning_tag
 
 
 def to_tuple(shape):
-    """Convert ints, arrays, and Nones to tuples
+    """Convert ints, arrays, and Nones to tuples.
 
     Parameters
     ----------
@@ -65,10 +61,10 @@ def to_tuple(shape):
         returned. If it is array-like, tuple(shape) is returned.
     """
     if shape is None:
-        return tuple()
+        return ()
     temp = np.atleast_1d(shape)
     if temp.size == 0:
-        return tuple()
+        return ()
     else:
         return tuple(temp)
 
@@ -150,7 +146,7 @@ def convert_size(size: Size) -> StrongSize | None:
 
 
 def shape_from_dims(dims: StrongDims, model) -> StrongShape:
-    """Determines shape from a `dims` tuple.
+    """Determine shape from a `dims` tuple.
 
     Parameters
     ----------
@@ -164,7 +160,6 @@ def shape_from_dims(dims: StrongDims, model) -> StrongShape:
     dims : tuple of (str or None)
         Names or None for all RV dimensions.
     """
-
     # Dims must be known already
     unknowndim_dims = set(dims) - set(model.dim_lengths)
     if unknowndim_dims:
@@ -180,7 +175,7 @@ def find_size(
     size: StrongSize | None,
     ndim_supp: int,
 ) -> StrongSize | None:
-    """Determines the size keyword argument for creating a Distribution.
+    """Determine the size keyword argument for creating a Distribution.
 
     Parameters
     ----------
@@ -197,7 +192,6 @@ def find_size(
     size : tuble of int or TensorVariable, optional
         The size argument for creating the Distribution
     """
-
     if size is not None:
         return size
 
@@ -210,7 +204,7 @@ def find_size(
 
 
 def rv_size_is_none(size: TensorVariable | Constant | None) -> bool:
-    """Check whether an rv size is None (i.e., NoneConst)"""
+    """Check whether an rv size is None (i.e., NoneConst)."""
     if size is None:
         return True
     return isinstance(size.type, NoneTypeT)
@@ -260,13 +254,13 @@ def change_dist_size(
 
     """
     # Check the dimensionality of the `new_size` kwarg
-    new_size_ndim = np.ndim(new_size)  # type: ignore
+    new_size_ndim = np.ndim(new_size)  # type: ignore[arg-type]
     if new_size_ndim > 1:
         raise ShapeError("The `new_size` must be ≤1-dimensional.", actual=new_size_ndim)
     elif new_size_ndim == 0:
-        new_size = (new_size,)  # type: ignore
+        new_size = (new_size,)  # type: ignore[assignment]
     else:
-        new_size = tuple(new_size)  # type: ignore
+        new_size = tuple(new_size)  # type: ignore[arg-type]
 
     op = dist.owner.op
     new_dist = _change_dist_size(op, dist, new_size=new_size, expand=expand)
@@ -331,7 +325,7 @@ def change_specify_shape_size(op, ss, new_size, expand) -> TensorVariable:
             new_shapes[-ndim_supp:] = shapes[-ndim_supp:]
 
     # specify_shape has a wrong signature https://github.com/aesara-devs/aesara/issues/1164
-    return pt.specify_shape(new_var, new_shapes)  # type: ignore
+    return pt.specify_shape(new_var, new_shapes)  # type: ignore[arg-type]
 
 
 def get_support_shape(
@@ -343,7 +337,7 @@ def get_support_shape(
     support_shape_offset: Sequence[int] | None = None,
     ndim_supp: int = 1,
 ) -> TensorVariable | None:
-    """Extract the support shapes from shape / dims / observed information
+    """Extract the support shapes from shape / dims / observed information.
 
     Parameters
     ----------
@@ -395,8 +389,7 @@ def get_support_shape(
             raise ValueError(f"Number of dims is too small for ndim_supp of {ndim_supp}")
         model = modelcontext(None)
         inferred_support_shape = [
-            model.dim_lengths[dims[i]] - support_shape_offset[i]  # type: ignore
-            for i in np.arange(-ndim_supp, 0)
+            model.dim_lengths[dims[i]] - support_shape_offset[i] for i in np.arange(-ndim_supp, 0)
         ]
 
     if inferred_support_shape is None and observed is not None:
@@ -439,7 +432,11 @@ def get_support_shape_1d(
     observed: Any | None = None,
     support_shape_offset: int = 0,
 ) -> TensorVariable | None:
-    """Helper function for cases when you just care about one dimension."""
+    """
+    Extract the support shapes from shape / dims / observed information.
+
+    Helper function for cases when you just care about one dimension.
+    """
     support_shape_tuple = get_support_shape(
         support_shape=(support_shape,) if support_shape is not None else None,
         shape=shape,
