@@ -244,7 +244,7 @@ def replace_vars_in_graphs(
 
 def inputvars(a):
     """
-    Get the inputs into PyTensor variables
+    Get the inputs into PyTensor variables.
 
     Parameters
     ----------
@@ -263,7 +263,7 @@ def inputvars(a):
 
 def cont_inputs(a):
     """
-    Get the continuous inputs into PyTensor variables
+    Get the continuous inputs into PyTensor variables.
 
     Parameters
     ----------
@@ -277,9 +277,7 @@ def cont_inputs(a):
 
 
 def floatX(X):
-    """
-    Convert an PyTensor tensor or numpy array to pytensor.config.floatX type.
-    """
+    """Convert a PyTensor tensor or numpy array to pytensor.config.floatX type."""
     try:
         return X.astype(pytensor.config.floatX)
     except AttributeError:
@@ -291,9 +289,7 @@ _conversion_map = {"float64": "int32", "float32": "int16", "float16": "int8", "f
 
 
 def intX(X):
-    """
-    Convert a pytensor tensor or numpy array to pytensor.tensor.int32 type.
-    """
+    """Convert a pytensor tensor or numpy array to pytensor.tensor.int32 type."""
     intX = _conversion_map[pytensor.config.floatX]
     try:
         return X.astype(intX)
@@ -303,9 +299,7 @@ def intX(X):
 
 
 def smartfloatX(x):
-    """
-    Converts numpy float values to floatX and leaves values of other types unchanged.
-    """
+    """Convert numpy float values to floatX and leaves values of other types unchanged."""
     if str(x.dtype).startswith("float"):
         x = floatX(x)
     return x
@@ -325,7 +319,7 @@ PyTensor derivative functions
 
 
 def gradient1(f, v):
-    """flat gradient of f wrt v"""
+    """Flat gradient of f wrt v."""
     return pt.flatten(grad(f, v, disconnected_inputs="warn"))
 
 
@@ -343,7 +337,7 @@ def gradient(f, vars=None):
 
 
 def jacobian1(f, v):
-    """jacobian of f wrt v"""
+    """Jacobian of f wrt v."""
     f = pt.flatten(f)
     idx = pt.arange(f.shape[0], dtype="int32")
 
@@ -446,7 +440,7 @@ identity = Elemwise(scalar_identity, name="identity")
 
 def make_shared_replacements(point, vars, model):
     """
-    Makes shared replacements for all *other* variables than the ones passed.
+    Make shared replacements for all *other* variables than the ones passed.
 
     This way functions can be called many times without setting unchanging variables. Allows us
     to use func.trust_input by removing the need for DictToArrayBijection and kwargs.
@@ -476,8 +470,7 @@ def join_nonshared_inputs(
     make_inputs_shared: bool = False,
 ) -> tuple[list[TensorVariable], TensorVariable]:
     """
-    Create new outputs and input TensorVariables where the non-shared inputs are joined
-    in a single raveled vector input.
+    Create new outputs and input TensorVariables where the non-shared inputs are joined in a single raveled vector input.
 
     Parameters
     ----------
@@ -640,15 +633,13 @@ class PointFunc:
 
 
 class CallableTensor:
-    """Turns a symbolic variable with one input into a function that returns symbolic arguments
-    with the one variable replaced with the input.
-    """
+    """Turns a symbolic variable with one input into a function that returns symbolic arguments with the one variable replaced with the input."""
 
     def __init__(self, tensor):
         self.tensor = tensor
 
     def __call__(self, input):
-        """Replaces the single input of symbolic variable to be the passed argument.
+        """Replace the single input of symbolic variable to be the passed argument.
 
         Parameters
         ----------
@@ -729,7 +720,8 @@ class GeneratorOp(Op):
 
 def generator(gen, default=None):
     """
-    Generator variable with possibility to set default value and new generator.
+    Create a generator variable with possibility to set default value and new generator.
+
     If generator is exhausted variable will produce default value if it is not None,
     else raises `StopIteration` exception that can be caught on runtime.
 
@@ -751,7 +743,7 @@ def generator(gen, default=None):
 
 def ix_(*args):
     """
-    PyTensor np.ix_ analog
+    PyTensor np.ix_ analog.
 
     See numpy.lib.index_tricks.ix_ for reference
     """
@@ -778,14 +770,14 @@ def largest_common_dtype(tensors):
 def find_rng_nodes(
     variables: Iterable[Variable],
 ) -> list[RandomGeneratorSharedVariable]:
-    """Return shared RNG variables in a graph"""
+    """Return shared RNG variables in a graph."""
     return [
         node for node in graph_inputs(variables) if isinstance(node, RandomGeneratorSharedVariable)
     ]
 
 
 def replace_rng_nodes(outputs: Sequence[TensorVariable]) -> list[TensorVariable]:
-    """Replace any RNG nodes upstream of outputs by new RNGs of the same type
+    """Replace any RNG nodes upstream of outputs by new RNGs of the same type.
 
     This can be used when combining a pre-existing graph with a cloned one, to ensure
     RNGs are unique across the two graphs.
@@ -809,7 +801,7 @@ def reseed_rngs(
     rngs: Sequence[SharedVariable],
     seed: SeedSequenceSeed,
 ) -> None:
-    """Create a new set of RandomState/Generator for each rng based on a seed"""
+    """Create a new set of RandomState/Generator for each rng based on a seed."""
     bit_generators = [
         np.random.PCG64(sub_seed) for sub_seed in np.random.SeedSequence(seed).spawn(len(rngs))
     ]
@@ -1092,9 +1084,7 @@ def constant_fold(
 
 
 def rewrite_pregrad(graph):
-    """Apply simplifying or stabilizing rewrites to graph that are safe to use
-    pre-grad.
-    """
+    """Apply simplifying or stabilizing rewrites to graph that are safe to use pre-grad."""
     return rewrite_graph(graph, include=("canonicalize", "stabilize"))
 
 
@@ -1142,7 +1132,7 @@ def toposort_replace(
 
 
 def normalize_rng_param(rng: None | Variable) -> Variable:
-    """Validate rng is a valid type or create a new one if None"""
+    """Validate rng is a valid type or create a new one if None."""
     if rng is None:
         rng = pytensor.shared(np.random.default_rng())
     elif not isinstance(rng.type, RandomType):
