@@ -11,6 +11,7 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
+import copy
 import pickle
 import threading
 import traceback
@@ -320,7 +321,7 @@ class TestValueGradFunction(unittest.TestCase):
     def setUp(self):
         extra1 = pt.iscalar("extra1")
         extra1_ = np.array(0, dtype=extra1.dtype)
-        extra1.dshape = tuple()
+        extra1.dshape = ()
         extra1.dsize = 1
 
         val1 = pt.vector("val1")
@@ -810,9 +811,9 @@ def test_datalogp_multiple_shapes():
 
 
 def test_nested_model_coords():
-    with pm.Model(name="m1", coords=dict(dim1=range(2))) as m1:
+    with pm.Model(name="m1", coords={"dim1": range(2)}) as m1:
         a = pm.Normal("a", dims="dim1")
-        with pm.Model(name="m2", coords=dict(dim2=range(4))) as m2:
+        with pm.Model(name="m2", coords={"dim2": range(4)}) as m2:
             b = pm.Normal("b", dims="dim1")
             m1.add_coord("dim3", range(4))
             c = pm.HalfNormal("c", dims="dim3")
@@ -836,7 +837,7 @@ class TestSetUpdateCoords:
             # Does not resize dim
             pmodel.set_data("m", [3, 4])
             # Resizes, but also passes new coords
-            pmodel.set_data("m", [1, 2, 3], coords=dict(dim_with_coords=[1, 2, 3]))
+            pmodel.set_data("m", [1, 2, 3], coords={"dim_with_coords": [1, 2, 3]})
 
             # Resizes, but does not pass new coords
             with pytest.raises(ValueError, match="'m' variable already had 3"):
@@ -970,12 +971,12 @@ class TestSetUpdateCoords:
         # Now the other way around.
         with warnings.catch_warnings():
             warnings.simplefilter("error")
-            pmodel.set_data("mdata", [1, 2, 3, 4], coords=dict(mdim=["A", "B", "C", "D"]))
+            pmodel.set_data("mdata", [1, 2, 3, 4], coords={"mdim": ["A", "B", "C", "D"]})
         assert pmodel.coords["mdim"] == ("A", "B", "C", "D")
 
         # This time with incorrectly sized coord values
         with pytest.raises(ShapeError, match="new coordinate values"):
-            pmodel.set_data("mdata", [1, 2], coords=dict(mdim=[1, 2, 3]))
+            pmodel.set_data("mdata", [1, 2], coords={"mdim": [1, 2, 3]})
 
     def test_set_data_warns_on_resize_of_dims_defined_by_other_data(self):
         with pm.Model() as pmodel:
@@ -1761,3 +1762,48 @@ class TestModelGraphs:
                 figsize=None,
                 dpi=300,
             )
+
+
+class TestModelCopy:
+    @pytest.mark.parametrize("copy_method", (copy.copy, copy.deepcopy))
+    def test_copy_model(self, copy_method) -> None:
+        with pm.Model() as simple_model:
+            pm.Normal("y")
+
+        copy_simple_model = copy_method(simple_model)
+
+        with simple_model:
+            simple_model_prior_predictive = pm.sample_prior_predictive(samples=1, random_seed=42)
+
+        with copy_simple_model:
+            z = pm.Deterministic("z", copy_simple_model["y"] + 1)
+            copy_simple_model_prior_predictive = pm.sample_prior_predictive(
+                samples=1, random_seed=42
+            )
+
+        assert (
+            simple_model_prior_predictive["prior"]["y"].values
+            == copy_simple_model_prior_predictive["prior"]["y"].values
+        )
+
+        assert "z" in copy_simple_model.named_vars
+        assert "z" not in simple_model.named_vars
+        assert (
+            copy_simple_model_prior_predictive["prior"]["z"].values
+            == 1 + simple_model_prior_predictive["prior"]["y"].values
+        )
+
+    @pytest.mark.parametrize("copy_method", (copy.copy, copy.deepcopy))
+    def test_guassian_process_copy_failure(self, copy_method) -> None:
+        with pm.Model() as gaussian_process_model:
+            ell = pm.Gamma("ell", alpha=2, beta=1)
+            cov = 2 * pm.gp.cov.ExpQuad(1, ell)
+            gp = pm.gp.Latent(cov_func=cov)
+            f = gp.prior("f", X=np.arange(10)[:, None])
+            pm.Normal("y", f * 2)
+
+        with pytest.warns(
+            UserWarning,
+            match="Detected variables likely created by GP objects. Further use of these old GP objects should be avoided as it may reintroduce variables from the old model. See issue: https://github.com/pymc-devs/pymc/issues/6883",
+        ):
+            copy_method(gaussian_process_model)
